@@ -3,27 +3,45 @@
 # Xpra is released under the terms of the GNU GPL v2, or, at your option, any
 # later version. See the file COPYING for details.
 
+from xpra.common import DETECT_MEMLEAKS, DETECT_FDLEAKS, CPUINFO
+
+
+debug = DETECT_MEMLEAKS or DETECT_FDLEAKS or CPUINFO
+watcher = True
+power = True
+suspend = True
+idle = True
 control = True
-notifications = True
+mdns = True
+notification = True
 webcam = True
 clipboard = True
 audio = True
+pulseaudio = True
 av_sync = True
-fileprint = True
+file = True
+printer = True
 mmap = True
 ssl = True
 ssh = True
-input_devices = True
-commands = True
+keyboard = True
+pointer = True
+command = True
 gstreamer = True
 x11 = True
 dbus = True
 encoding = True
 logging = True
-network_state = True
+ping = True
+bandwidth = True
 shell = False
 display = True
-windows = True
-cursors = True
+window = True
+cursor = True
 rfb = True
 http = True
+gtk = True
+tray = True
+opengl = True
+bell = True
+systray = True
